LudoController class

Inheritance

Constructors

LudoController({required List<LudoPlayer> players, LudoDiceRules diceRules = const LudoDiceRules(), int diceRoller()?, LudoDiceRolledCallback? onDiceRolled, LudoPieceMovedCallback? onPieceMoved, LudoPieceCapturedCallback? onPieceCaptured, LudoTurnChangedCallback? onTurnChanged, LudoPlayerWonCallback? onPlayerWon, LudoTeamWonCallback? onTeamWon, LudoGameFinishedCallback? onGameFinished, bool enableAudio = true, Duration stepAnimationDuration = const Duration(milliseconds: 180), List<LudoTeam>? teams})

Properties

animatingPiece LudoPiece?
no setter
diceRules LudoDiceRules
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAnimating bool
no setter
isTeamsMode bool
no setter
onDiceRolled LudoDiceRolledCallback?
final
onGameFinished LudoGameFinishedCallback?
final
onPieceCaptured LudoPieceCapturedCallback?
final
onPieceMoved LudoPieceMovedCallback?
final
onPlayerWon LudoPlayerWonCallback?
final
onTeamWon LudoTeamWonCallback?
final
onTurnChanged LudoDiceRolledCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state LudoGameState
no setter
stepAnimationDuration Duration
final
teams List<LudoTeam>?
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
rollDice() int
selectPiece(int pieceId) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited