LudoTeamWonCallback typedef
LudoTeamWonCallback =
void Function(LudoTeam team)
Fired when a full team wins in teams mode.
team is the winning team, place is always 1 (first place).
Implementation
typedef LudoTeamWonCallback = void Function(LudoTeam team);