LudoEngine class

Pure stateless engine. Pass teams to enable teams mode.

Constructors

LudoEngine(LudoDiceRules diceRules, {List<LudoTeam>? teams})
const

Properties

diceRules LudoDiceRules
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teams List<LudoTeam>?
Non-null → teams mode active.
final

Methods

move(LudoGameState state, int pieceId) LudoEngineMoveResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
roll(LudoGameState state, int diceValue) LudoEngineRollResult
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited