LudoEngineMoveResult class

Constructors

LudoEngineMoveResult({required LudoGameState state, required LudoPiece movedPiece, required int fromPosition, required int toPosition, required List<LudoPiece> capturedPieces, required bool playerWon, required bool teamWon, required bool turnPassed, required bool gameFinished})
const

Properties

capturedPieces List<LudoPiece>
final
fromPosition int
final
gameFinished bool
final
hashCode int
The hash code for this object.
no setterinherited
movedPiece LudoPiece
final
playerWon bool
True if the individual player just placed their 4th piece home.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state LudoGameState
final
teamWon bool
True if this move caused the whole TEAM to win (teams mode only).
final
toPosition int
final
turnPassed bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited