rules/piece_state_rules library
Functions
-
resolvePieceState(
LudoPiece piece) → LudoPieceState -
Derives
piece's current LudoPieceState, using the fixed board geometry to determine whether it currently sits on a safe cell.
piece's current LudoPieceState, using the fixed board
geometry to determine whether it currently sits on a safe cell.